@@ -12,11 +12,13 @@ from hachoir_parser import HachoirParser
 from hachoir_core.field import FieldSet, RootSeekableFieldSet, RawBytes
 from hachoir_core.endian import LITTLE_ENDIAN
 from hachoir_core.stream import StringInputStream
-from hachoir_parser.misc.msoffice_summary import Summary, CompObj
+from hachoir_parser.misc.msoffice_summary import SummaryFieldSet, CompObj
+from hachoir_parser.misc.word_doc import WordDocumentFieldSet
 
 PROPERTY_NAME = {
     u"\5DocumentSummaryInformation": "doc_summary",
     u"\5SummaryInformation": "summary",
+    u"WordDocument": "word_doc",
 }
 
 class OfficeRootEntry(HachoirParser, RootSeekableFieldSet):
@@ -54,9 +56,8 @@ class OfficeRootEntry(HachoirParser, RootSeekableFieldSet):
         previous = None
         size = 0
         start = property["start"].value
-        chain = ole2.getChain(start, ole2.ss_fat)
+        chain = ole2.getChain(start, True)
         blocksize = ole2.ss_size
-        seek = ole2.seekSBlock
         desc_format = "Small blocks %s..%s (%s)"
         fragment_group = None
         while True:
@@ -74,10 +75,13 @@ class OfficeRootEntry(HachoirParser, RootSeekableFieldSet):
                     continue
             except StopIteration:
                 block = None
-            seek(first)
+            self.seekSBlock(first)
             desc = desc_format % (first, previous, previous-first+1)
+            size = min(size, property["size"].value*8)
             if name_prefix in ("summary", "doc_summary"):
-                yield Summary(self, name, desc, size=size)
+                yield SummaryFieldSet(self, name, desc, size=size)
+            elif name_prefix == "word_doc":
+                yield WordDocumentFieldSet(self, name, desc, size=size)
             elif property_index == 1:
                 yield CompObj(self, "comp_obj", desc, size=size)
             else:
@@ -88,6 +92,9 @@ class OfficeRootEntry(HachoirParser, RootSeekableFieldSet):
             previous = block
             size = ole2.sector_size
 
+    def seekSBlock(self, block):
+        self.seekBit(block * self.ole2.ss_size)
+
 class FragmentGroup:
     def __init__(self, parser):
         self.items = []
