@@ -1,8 +1,17 @@
+"""
+Microsoft Document summaries structures.
+
+Documents
+---------
+
+ - Apache POI (HPSF Internals):
+   http://poi.apache.org/hpsf/internals.html
+"""
 from hachoir_parser import HachoirParser
 from hachoir_core.field import (FieldSet, ParserError,
     RootSeekableFieldSet, SeekableFieldSet,
     Bit, Bits, NullBits,
-    UInt8, UInt16, UInt32, TimestampWin64, Enum,
+    UInt8, UInt16, UInt32, TimestampWin64, TimedeltaWin64, Enum,
     Bytes, RawBytes, NullBytes, String,
     Int8, Int16, Int32, Float32, Float64, PascalString32)
 from hachoir_core.text_handler import textHandler, hexadecimal, filesizeHandler
@@ -32,6 +41,8 @@ class OSConfig:
             self.utf16 = "UTF-16-LE"
 
 class PropertyIndex(FieldSet):
+    TAG_CODEPAGE = 1
+
     COMMON_PROPERTY = {
         0: "Dictionary",
         1: "CodePage",
@@ -158,8 +169,8 @@ class PropertyContent(FieldSet):
     TYPE_INFO = {
         0: ("EMPTY", None),
         1: ("NULL", None),
-        2: ("Int16", Int16),
-        3: ("Int32", Int32),
+        2: ("UInt16", UInt16),
+        3: ("UInt32", UInt32),
         4: ("Float32", Float32),
         5: ("Float64", Float64),
         6: ("CY", None),
@@ -201,6 +212,7 @@ class PropertyContent(FieldSet):
     TYPE_NAME = createDict(TYPE_INFO, 0)
 
     def createFields(self):
+        self.osconfig = self.parent.osconfig
         if True:
             yield Enum(Bits(self, "type", 12), self.TYPE_NAME)
             yield Bit(self, "is_vector")
@@ -212,11 +224,14 @@ class PropertyContent(FieldSet):
         try:
             handler = self.TYPE_INFO[tag][1]
             if handler == PascalString32:
-                osconfig = self["../.."].osconfig
+                osconfig = self.osconfig
                 if tag == self.TYPE_LPSTR:
                     kw["charset"] = osconfig.charset
                 else:
                     kw["charset"] = osconfig.utf16
+            elif handler == TimestampWin64:
+                if self.description == "TotalEditingTime":
+                    handler = TimedeltaWin64
         except LookupError:
             handler = None
         if not handler:
@@ -232,11 +247,18 @@ class PropertyContent(FieldSet):
 PropertyContent.TYPE_INFO[12] = ("VARIANT", PropertyContent)
 
 class SummarySection(SeekableFieldSet):
+    CODEPAGE_CHARSET = {
+        1252: "WINDOWS-1252",
+        1253: "WINDOWS-1253",
+        65001: "UTF-8",
+    }
+
     def __init__(self, *args):
         SeekableFieldSet.__init__(self, *args)
         self._size = self["size"].value * 8
 
     def createFields(self):
+        self.osconfig = self.parent.osconfig
         yield UInt32(self, "size")
         yield UInt32(self, "property_count")
         for index in xrange(self["property_count"].value):
@@ -244,7 +266,15 @@ class SummarySection(SeekableFieldSet):
         for index in xrange(self["property_count"].value):
             findex = self["property_index[%u]" % index]
             self.seekByte(findex["offset"].value)
-            yield PropertyContent(self, "property[]", findex["id"].display)
+            field = PropertyContent(self, "property[]", findex["id"].display)
+            yield field
+            if not self.osconfig.charset \
+            and findex['id'].value == PropertyIndex.TAG_CODEPAGE:
+                codepage = field['value'].value
+                if codepage in self.CODEPAGE_CHARSET:
+                    self.osconfig.charset = self.CODEPAGE_CHARSET.get(codepage)
+                else:
+                    self.warning("Unknown codepage: %r" % codepage)
 
 class SummaryIndex(FieldSet):
     static_size = 20*8
@@ -252,15 +282,10 @@ class SummaryIndex(FieldSet):
         yield String(self, "name", 16)
         yield UInt32(self, "offset")
 
-class Summary(HachoirParser, RootSeekableFieldSet):
-    PARSER_TAGS = {
-        "description": "Microsoft Office document subfragments",
-    }
+class BaseSummary:
     endian = LITTLE_ENDIAN
 
-    def __init__(self, stream, **args):
-        RootSeekableFieldSet.__init__(self, None, "root", stream, None, stream.askSize(self))
-        HachoirParser.__init__(self, stream, **args)
+    def __init__(self):
         if self["endian"].value == "\xFF\xFE":
             self.endian = BIG_ENDIAN
         elif self["endian"].value == "\xFE\xFF":
@@ -269,10 +294,6 @@ class Summary(HachoirParser, RootSeekableFieldSet):
             raise ParserError("OLE2: Invalid endian value")
         self.osconfig = OSConfig(self["os_type"].value == OS_MAC)
 
-    def validate(self):
-        return True
-
-
     def createFields(self):
         yield Bytes(self, "endian", 2, "Endian (0xFF 0xFE for Intel)")
         yield UInt16(self, "format", "Format (0)")
@@ -298,6 +319,24 @@ class Summary(HachoirParser, RootSeekableFieldSet):
         if 0 < size:
             yield NullBytes(self, "end_padding", size)
 
+class SummaryParser(BaseSummary, HachoirParser, RootSeekableFieldSet):
+    PARSER_TAGS = {
+        "description": "Microsoft Office summary",
+    }
+
+    def __init__(self, stream, **kw):
+        RootSeekableFieldSet.__init__(self, None, "root", stream, None, stream.askSize(self))
+        HachoirParser.__init__(self, stream, **kw)
+        BaseSummary.__init__(self)
+
+    def validate(self):
+        return True
+
+class SummaryFieldSet(BaseSummary, FieldSet):
+    def __init__(self, parent, name, description=None, size=None):
+        FieldSet.__init__(self, parent, name, description=description, size=size)
+        BaseSummary.__init__(self)
+
 class CompObj(FieldSet):
     OS_VERSION = {
         0x0a03: "Windows 3.1",
