@@ -13,13 +13,13 @@ Creation: 5 august 2006
 from hachoir_parser import Parser
 from hachoir_core.field import (FieldSet, ParserError,
     UInt16, UInt32, UInt64,
-    TimestampWin64,
+    TimestampWin64, TimedeltaWin64,
     String, PascalString16, Enum,
     Bit, Bits, PaddingBits,
     PaddingBytes, NullBytes, RawBytes)
 from hachoir_core.endian import LITTLE_ENDIAN
 from hachoir_core.text_handler import (
-    textHandler, displayHandler, filesizeHandler, durationWin64)
+    textHandler, displayHandler, filesizeHandler)
 from hachoir_core.tools import humanBitRate
 from itertools import izip
 from hachoir_parser.video.fourcc import audio_codec_name, video_fourcc_name
@@ -84,8 +84,8 @@ class FileProperty(FieldSet):
         yield filesizeHandler(UInt64(self, "file_size"))
         yield TimestampWin64(self, "creation_date")
         yield UInt64(self, "pckt_count")
-        yield textHandler(UInt64(self, "play_duration"), durationWin64)
-        yield textHandler(UInt64(self, "send_duration"), durationWin64)
+        yield TimedeltaWin64(self, "play_duration")
+        yield TimedeltaWin64(self, "send_duration")
         yield UInt64(self, "preroll")
         yield Bit(self, "broadcast", "Is broadcast?")
         yield Bit(self, "seekable", "Seekable stream?")
@@ -199,7 +199,7 @@ class SimpleIndex(FieldSet):
 
     def createFields(self):
         yield GUID(self, "file_id")
-        yield textHandler(UInt64(self, "entry_interval"), durationWin64)
+        yield TimedeltaWin64(self, "entry_interval")
         yield UInt32(self, "max_pckt_count")
         yield UInt32(self, "entry_count")
         for index in xrange(self["entry_count"].value):
